@@ -25,9 +25,3 @@ function(object, maxdist, n = 200, min=1.0e-6 * maxdist, dir = c(1,0,0),
 	else
 		data.frame(dist=ret[[1]], gamma=ret[[2]])
 }
-
-"variogram.line" <- function(..., deprecate = TRUE) {
-	if (deprecate)
-		cat("variogram.line is DEPRECATED, please use variogramLine instead\n")
-	variogramLine(...)
-}
