@@ -3,6 +3,11 @@ suppressPackageStartupMessages(library(spacetime))
 suppressPackageStartupMessages(library(gstat))
 suppressPackageStartupMessages(library(stars))
 
+Sys.unsetenv("KMP_DEVICE_THREAD_LIMIT")
+Sys.unsetenv("KMP_ALL_THREADS")
+Sys.unsetenv("KMP_TEAMS_THREAD_LIMIT")
+Sys.unsetenv("OMP_THREAD_LIMIT")
+
 data(wind)
 wind.loc$y = as.numeric(char2dms(as.character(wind.loc[["Latitude"]])))
 wind.loc$x = as.numeric(char2dms(as.character(wind.loc[["Longitude"]])))
@@ -23,19 +28,17 @@ velocities = apply(windsqrt, 2, function(x) { x - meanwind })
 # proper Euclidian (projected) space:
 pts = coordinates(wind.loc[match(names(wind[4:15]), wind.loc$Code),])
 pts = SpatialPoints(pts)
-#if (require(rgdal) && require(maps)) {
+if (require(sp, quietly = TRUE) && require(maps, quietly = TRUE)) {
 proj4string(pts) = "+proj=longlat +datum=WGS84 +ellps=WGS84"
-utm29 = CRS("+proj=utm +zone=29 +datum=WGS84 +ellps=WGS84")
-pts = spTransform(pts, utm29)
+utm29 = "+proj=utm +zone=29 +datum=WGS84 +ellps=WGS84"
+pts = as(st_transform(st_as_sfc(pts), utm29), "Spatial")
 # note the t() in:
 w = STFDF(pts, wind$time, data.frame(values = as.vector(t(velocities))))
 
 library(mapdata)
-library(maptools)
-m = map2SpatialLines(
-    map("worldHires", xlim = c(-11,-5.4), ylim = c(51,55.5), plot=F))
-proj4string(m) = "+proj=longlat +datum=WGS84 +ellps=WGS84"
-m = spTransform(m, utm29)
+mp = map("worldHires", xlim = c(-11,-5.4), ylim = c(51,55.5), plot=FALSE)
+sf = st_transform(st_as_sf(mp, fill = FALSE), utm29)
+m = as(sf, "Spatial")
 
 # setup grid
 grd = SpatialPixels(SpatialPoints(makegrid(m, n = 300)),
@@ -70,7 +73,6 @@ v = vgmST("separable",
 wind.ST = krigeST(sqrt(values)~1, w, STF(grd, tgrd), v)
 
 all.equal(wind.pr0, wind.ST)
-#}
 
 # stars:
 df = data.frame(a = rep(NA, 324*10))
@@ -98,3 +100,4 @@ st_bbox(rt)
 
 # 6:
 stplot(as(st_as_stars(wind.ST), "STFDF"))
+}
